.. py:function:: sf_pochrel_e(a, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_pochrel_e`
    c code signature: int gsl_sf_pochrel_e(const double a, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_poch(a, x [, ret])

    Wrapper for :c:func:`gsl_sf_poch`
    c code signature: double gsl_sf_poch(const double a, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_lnpoch_e(a, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_lnpoch_e`
    c code signature: int gsl_sf_lnpoch_e(const double a, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_lnpoch(a, x [, ret])

    Wrapper for :c:func:`gsl_sf_lnpoch`
    c code signature: double gsl_sf_lnpoch(const double a, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_poch_e(a, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_poch_e`
    c code signature: int gsl_sf_poch_e(const double a, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_pochrel(a, x [, ret])

    Wrapper for :c:func:`gsl_sf_pochrel`
    c code signature: double gsl_sf_pochrel(const double a, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_lnpoch_sgn_e(a, x [, ret, sgn, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_lnpoch_sgn_e`
    c code signature: int gsl_sf_lnpoch_sgn_e(const double a, const double x, gsl_sf_result* result, double* sgn)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Od_rd`
    
    :param double a: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double sgn: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 2, :param double sgn: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

